CInput class

Inheritance

Constructors

CInput({Key? key, required String labelText, required TextEditingController controller, String? errorText, TextInputType keyboardType = TextInputType.text, Widget? prefixIcon, Widget? suffixIcon, String? prefixText, String? hintText, ValueChanged<String>? onChanged, bool obscureText = false, bool readOnly = false, VoidCallback? onTap, FocusNode? focusNode, bool? enabled, List<TextInputFormatter>? inputFormatters, TextInputAction? textInputAction, ValueChanged<String>? onSubmitted, TextCapitalization? textCapitalization, TextStyle? prefixStyle, bool isRequired = false, Color? background, Color? textColor})
const

Properties

background Color?
final
controller TextEditingController
final
enabled bool?
final
errorText String?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
final
inputFormatters List<TextInputFormatter>?
final
isRequired bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType
final
labelText String
final
obscureText bool
final
onChanged ValueChanged<String>?
final
onSubmitted ValueChanged<String>?
final
onTap VoidCallback?
final
prefixIcon Widget?
final
prefixStyle TextStyle?
final
prefixText String?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon Widget?
final
textCapitalization TextCapitalization?
final
textColor Color?
final
textInputAction TextInputAction?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited