Gaps class

Constructors

Gaps()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

hLg → const SizedBox
hMd → const SizedBox
hSm → const SizedBox
hXl → const SizedBox
hXs → const SizedBox
hXxl → const SizedBox
hXxs → const SizedBox
hXxxl → const SizedBox
lg → const double
md → const double
sm → const double
wLg → const SizedBox
wMd → const SizedBox
wSm → const SizedBox
wXl → const SizedBox
wXs → const SizedBox
wXss → const SizedBox
wXxl → const SizedBox
wXxs → const SizedBox
wXxxl → const SizedBox
xl → const double
xs → const double
xss → const double
xxl → const double
xxs → const double
xxxl → const double