$Svg class

Constructors

$Svg()
const

Properties

feedback AssetsSvg
no setter
hashCode int
The hash code for this object.
no setterinherited
ic_add AssetsSvg
no setter
ic_back AssetsSvg
no setter
ic_bn_home AssetsSvg
no setter
ic_bn_home_fill AssetsSvg
no setter
ic_bn_portfolio AssetsSvg
no setter
ic_bn_portfolio_fill AssetsSvg
no setter
ic_bn_profile AssetsSvg
no setter
ic_bn_profile_fill AssetsSvg
no setter
ic_bn_transaction AssetsSvg
no setter
ic_bn_transaction_fill AssetsSvg
no setter
ic_copy AssetsSvg
no setter
ic_down AssetsSvg
no setter
ic_download AssetsSvg
no setter
no setter
ic_logout AssetsSvg
no setter
ic_next AssetsSvg
no setter
ic_repay AssetsSvg
no setter
ic_verify AssetsSvg
no setter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited