DashboardSummaryModel class
Constructors
-
DashboardSummaryModel({String? totalLoan, String? utilisedAmount, String? balance, String? loanCount, List<
LoanDetailModel> ? loans}) -
DashboardSummaryModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- balance → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loanCount → String?
-
final
-
loans
→ List<
LoanDetailModel> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalLoan → String?
-
final
- utilisedAmount → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited