LoanDetailModel class
Constructors
- LoanDetailModel({String? reqId, bool? isApply, bool? isContinue, bool? isCancel, String? name, String? availableCreditLimit, String? withdrawn, String? interestRate, String? mfPledges, String? accountNumber, String? accountIfsc, String? clientBankName, UpcomingRepayment? upcomingRepayment, String? availableAmount, String? drawingPower, dynamic lan, String? fas, String? shortfallAmount, String? journeyType, String? lenderName, bool? isPmrUploaded, bool? isCmrUploaded, String? pmrUrl, String? cmrUrl})
-
LoanDetailModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountIfsc → String?
-
final
- accountNumber → String?
-
final
- availableAmount → String?
-
final
- availableCreditLimit → String?
-
final
- clientBankName → String?
-
final
- cmrUrl → String?
-
final
- drawingPower → String?
-
final
- fas → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interestRate → String?
-
final
- isApply → bool?
-
final
- isCancel → bool?
-
final
-
final
- isCmrUploaded → bool?
-
final
- isContinue → bool?
-
final
-
final
- isPmrUploaded → bool?
-
final
-
no setter
- journeyType → String?
-
final
- lan → dynamic
-
final
- lenderName → String?
-
final
- mfPledges → String?
-
final
- name → String?
-
final
- pmrUrl → String?
-
final
- reqId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- shortfallAmount → String?
-
final
- upcomingRepayment → UpcomingRepayment?
-
final
- withdrawn → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited