UserActionsResult class

Constructors

UserActionsResult({String? status, UserActionsModel? data, String? message})
UserActionsResult.fromJson(Map<String, dynamic> json)
factory

Properties

data UserActionsModel?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited