IncreaseLimitUiState class

Constructors

IncreaseLimitUiState({bool showOtp = false, List<PledgeableFund> funds = const [], Set<int> selectedIndexes = const {}, IncreaseLimitView currentView = IncreaseLimitView.portfolioBreakdown})
const

Properties

currentView IncreaseLimitView
final
funds List<PledgeableFund>
🔹 FUND FLOW
final
hashCode int
The hash code for this object.
no setterinherited
projectedLimit double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndexes Set<int>
final
showOtp bool
🔹 PAN FLOW
final

Methods

copyWith({bool? showOtp, List<PledgeableFund>? funds, Set<int>? selectedIndexes, IncreaseLimitView? currentView}) IncreaseLimitUiState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited