LoginState class

Constructors

LoginState({LoginViewStatus viewStatus = LoginViewStatus.initial, bool isLoading = false, String? mobileError, String? otpError, String? snackbarMessage, String? pledgeStatus, String? lenderCode, String? isVcip, String? sharesStatus, String? token, String? otpRef, String? mobileLiveError, bool isLoginOtpVisible = false, int remainingSeconds = 60, bool canResend = false, PendingJourney? pendingJourney, String? kycStatus})
const

Properties

canResend bool
final
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
final
isLoginOtpVisible bool
final
isVcip String?
final
kycStatus String?
final
lenderCode String?
final
mobileError String?
final
mobileLiveError String?
final
otpError String?
final
otpRef String?
final
pendingJourney PendingJourney?
final
pledgeStatus String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
remainingSeconds int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharesStatus String?
final
snackbarMessage String?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
token String?
final
viewStatus LoginViewStatus
final

Methods

copyWith({LoginViewStatus? viewStatus, bool? isLoading, String? mobileError, String? otpError, String? snackbarMessage, String? pledgeStatus, String? lenderCode, String? isVcip, String? sharesStatus, String? kycStatus, String? token, String? otpRef, bool clearSnackbar = false, String? emailLiveError, String? mobileLiveError, bool? isLoginOtpVisible, int? remainingSeconds, bool? canResend, PendingJourney? pendingJourney}) LoginState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited