DigioService class

Constructors

DigioService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isUserCancelled bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCancelledState() → void
initializeSDK(String environment) Future<Result<void>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetProcessingState() → void
startKYC({required String customerId, required String identifier, required String accessToken}) Future<Result<String>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited