IncreaseLimitModel class

Constructors

IncreaseLimitModel({String? reqId, String? mobileNumber, String? pan, String? name, String? email, DateTime? dob, String? birthDate, String? lenderId, String? kycStatus, String? otpStatus, String? topUpReqId})
IncreaseLimitModel.fromJson(Map<String, dynamic> json)
factory

Properties

birthDate String?
final
dob DateTime?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
kycStatus String?
final
lenderId String?
final
mobileNumber String?
final
name String?
final
otpStatus String?
final
pan String?
final
reqId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topUpReqId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited