RepayModel class

Constructors

RepayModel({String? accountNumber, String? ifscCode, String? beneficiaryName, String? bankName, String? branchName, String? type, })
RepayModel.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumber String?
final
final
bankName String?
final
beneficiaryName String?
final
branchName String?
final
hashCode int
The hash code for this object.
no setterinherited
ifscCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited