LamfSdk class
Constructors
- LamfSdk()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
launch(
BuildContext context, {String? token, required String mobileNumber, ThemeData? theme, String? redirectUrl, String? otpRef, String? reqId, List< SdkJourney> ? allowedJourneys, String environment = 'prod'}) → Future<void> -
Launch the LAMF SDK journey directly.
The
contextis the BuildContext from the host application.