PledgeMfResponse class

Constructors

PledgeMfResponse({String? status, Map<String, dynamic>? data, String? message, String? error})
PledgeMfResponse.error(String errorMessage, {String? message})
factory
PledgeMfResponse.fromJson(Map<String, dynamic> json)
factory

Properties

data Map<String, dynamic>?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final

Methods

extractInnerStatus() String?
Robust extraction: handles String, List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited