PledgeableFund class

Constructors

PledgeableFund({required String fundName, required double fundValue, required String fundCode, required double lienEligibleUnits, required double nav, required double availableAmount, required double availableUnits, required String amcCode, required String schemeCode, required String folioNo, required String rtaName, double? updatedFundAmount, bool enabled = false, bool active = false})
const
PledgeableFund.empty()
factory
PledgeableFund.fromJson(Map<String, dynamic> json)
--- JSON Parsing Helpers ---
factory

Properties

active bool
final
amcCode String
final
availableAmount double
final
availableUnits double
final
enabled bool
final
folioNo String
final
fundCode String
final
fundName String
final
fundValue double
final
hashCode int
The hash code for this object.
no setterinherited
lienEligibleUnits double
final
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rtaName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemeCode String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
updatedFundAmount double?
final

Methods

copyWith({String? fundName, double? fundValue, String? fundCode, double? lienEligibleUnits, double? nav, double? availableAmount, double? availableUnits, String? amcCode, String? schemeCode, String? folioNo, String? rtaName, double? updatedFundAmount, bool? enabled, bool? active}) PledgeableFund
--- Copy helper ---
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited