KycWebhookData class

Constructors

KycWebhookData({required String kycStatus, required String loanCreationId, required String bankName, required String reqId})
KycWebhookData.fromJson(Map<String, dynamic> json)
factory

Properties

bankName String
final
hashCode int
The hash code for this object.
no setterinherited
kycStatus String
final
loanCreationId String
final
reqId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited