BR class

Constructors

BR()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

c100 BorderRadius
getter/setter pair
cLarge BorderRadius
getter/setter pair
cMedium BorderRadius
getter/setter pair
cSmall BorderRadius
getter/setter pair
cXLarge BorderRadius
getter/setter pair
cXSmall BorderRadius
getter/setter pair
cXXLarge BorderRadius
getter/setter pair
cXXSmall BorderRadius
getter/setter pair
cXXXLarge BorderRadius
getter/setter pair
cXXXSmall BorderRadius
getter/setter pair