EnumConverter<T> class

Constructors

EnumConverter(Map<dynamic, T> map)

Properties

hashCode int
The hash code for this object.
no setterinherited
map Map<dynamic, T>
getter/setter pair
reverse Map<T, dynamic>
no setter
reverseMap Map<T, dynamic>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited