Api class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
call({required ApiMethod method, required String name, String? baseUrl, ApiVersion version = ApiVersion.v1, String? contentType = Headers.jsonContentType, Map<String, dynamic>? queryParameters, Map<String, dynamic>? rawData = const {}, FormData? formData, dynamic onResponse(Map<String, dynamic>)?, dynamic onError(DioException)?, BuildContext? dialogContext, bool showSnack = true})
→ Future<ResponseResult?>
-
-
logout(String msg)
→ Future<void>
-