Rtr class

Constructors

Rtr()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

back({Object? result}) → void
off(Widget widget, {FutureOr<void> whenComplete()?, FutureOr then(dynamic value)?}) → void
offAll(Widget widget) → void
to(Widget widget, {FutureOr<void> whenComplete()?, FutureOr then(dynamic value)?}) → void