Str class
Constructors
- Str()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
Constants
- invalidAadhaar → const String
- invalidAccount → const String
- invalidAddress → const String
- invalidCode → const String
- invalidConfirmPassword → const String
- invalidDob → const String
- invalidEmail → const String
- invalidEmpty → const String
- invalidMobile → const String
- invalidName → const String
- invalidOtp → const String
- invalidPan → const String
- invalidPassword → const String
- loremLong → const String
- loremShort → const String
- notFound → const String
- passwordNotMatch → const String
- required → const String