AppTypography class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- body → TextStyle
-
no setter
- bodyMedium → TextStyle
-
no setter
- bodySecondary → TextStyle
-
no setter
- bodyWhite → TextStyle
-
no setter
- boldTxt ↔ TextStyle
-
getter/setter pair
-
no setter
-
no setter
- caption → TextStyle
-
no setter
- h0 → TextStyle
-
no setter
- h1 → TextStyle
-
no setter
- h2 → TextStyle
-
no setter
- h3 → TextStyle
-
no setter
- h4 → TextStyle
-
no setter
- overline → TextStyle
-
no setter
- regularTxt ↔ TextStyle
-
getter/setter pair
- semiTxt ↔ TextStyle
-
getter/setter pair
- subtitle → TextStyle
-
no setter