Data class
Constructors
- Data({String? mandateId, String? id, dynamic status, String? shortUrl, dynamic message, String? state, String? type, BankDetails? bankDetails, DateTime? createdAt, String? mode, ServiceProviderDetails? serviceProviderDetails, String? authenticationUrl})
-
Data.fromJson(Map<
String, dynamic> json) -
factory
Properties
- authenticationUrl → String?
-
final
- bankDetails → BankDetails?
-
final
- createdAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- mandateId → String?
-
final
- message → dynamic
-
final
- mode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceProviderDetails → ServiceProviderDetails?
-
final
- shortUrl → String?
-
final
- state → String?
-
final
- status → dynamic
-
final
- type → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited