UserActionsModel class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isApply → bool
-
final
- isCancel → bool
-
final
- isCmrUploaded → bool?
-
final
- isContinue → bool
-
final
- isPmrUploaded → bool?
-
final
- isTopUp → bool
-
final
- journeyType → String?
-
final
- kycStatus → String?
-
final
- reqId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited