Implementation
final Map<String, String> enUS = {
'title': 'SLiQ Demo',
'loading': 'Loading...',
'retry': 'Retry',
//login screen
'sliQ': 'SLiQ',
'email': 'Email',
'login': 'Login',
'password': 'Password',
'error': 'Something went wrong',
'EnterDetailsBelow': 'Enter Details Below',
'EmailAddress': 'Email Address',
'MobileNumber': 'Mobile Number',
'LoginSuccessful!': 'Login Successful!',
'EnterOTP': 'Enter 6-digit OTP',
'SendOTP': 'Send OTP',
'Continue': 'Continue',
'ResendOTP': 'Resend OTP',
'NoCode?': "Didn't get the code? ",
'Skip': 'Skip',
'GetStarted': 'Get Started',
'Next': 'Next',
//welcome screens
'welcome1_subtitle': 'Unlock Funds Instantly',
'welcome1_title':
'Get Easy, Fast, & secured loans without selling your investments.',
'welcome2_subtitle': 'Smart & Transparent Borrowing',
'welcome2_title': 'Competitive Rates. Flexible. Transparent.',
'welcome3_subtitle': 'Keep Your Assets, Unlock Value',
'welcome3_title': 'Liquidate funds while your investments continue to grow.',
//successs pledge
'congratulations': 'Congratulations!',
'loanSuccessMessage':
'Your loan application has been submitted successfully and is being processed.',
'goToDashboard': 'Go to Dashboard',
//form
'CheckEligibility': 'Check Eligibility',
'NextLenderSelection': 'Next: Offer Details',
'Submitting': 'Submitting...',
'Submit': 'Submit',
'Confirm&Continue': 'Confirm & Continue',
'selectInvestmentTitlePart1': 'Select The Investment You Want to ',
'selectInvestmentTitlePart2': 'Unlock Funds From',
'insurancePolicyTitle': 'Insurance Policy',
'insurancePolicySubtitle': 'Get loan against your life insurance policies.',
'mutualFundTitle': 'Mutual Fund',
'mutualFundSubtitle': 'Get funds while your MF stay invested.',
'sharesTitle': 'Shares',
'sharesSubtitle': 'Leverage your shares without selling them.',
'panCardNumberLabel': 'PAN Card Number',
'panCardNumberHint': 'Enter PAN Number',
'nameAsPerPanLabel': 'Name as Per PAN',
'nameAsPerPanHint': 'Enter Full Name',
'dateOfBirthLabel': 'Date of Birth',
'dateOfBirthHint': 'MM/DD/YYYY',
'checking': 'Checking...',
'checkLoanEligibility': 'Check Loan Eligibility',
'totalUnits': 'Total Unit',
'totalFundValue': 'Total Fund Value (₹@perUnit/Unit)',
'Nolendersavailable': 'No lenders available.',
'yourSelection': 'Your Selection',
'interestRate': 'ROI',
'loanAmount': 'Loan Amount',
'pledgeableMFs': 'Total MFs',
'chooseFundsHint': '',
// 'chooseFundsHint': 'Choose the Funds you wish to pledge, click to edit',
'cancel': 'Cancel',
'confirm': 'Confirm',
'amountExceedLimit': 'Amount cannot exceed eligible limit.',
'invalidAmount': 'Please enter a valid positive amount',
'continueWith': 'Continue with @lenderName',
'lenderSelectionTitle': 'Offer Details',
'nextKycVerification': 'Next: KYC Verification',
'goBack': 'Go Back',
'viewLenders': 'View Lenders',
'viewYourMfDetails': 'View Your MF Details',
'eligibleCreditLimit': 'Pledgeable Portfolio Value',
'totalPortfolioValue': 'Your Total Portfolio Value is @value',
'selectLenderInfo': 'Select a lender to proceed with your loan application.',
'portfolioBreakdown': 'Portfolio Breakdown',
'portfolioBreakdownPledgeableFunds': 'Portfolio Breakdown > Pledgeable Funds',
'refreshPortfolio': 'Refresh Portfolio',
"pledgeableFunds": "Pledgeable Funds",
"nonPledgeableFunds": "Non Pledgeable Funds",
"dematFunds": "Demat Funds",
"unapprovedFunds": "Unapproved Funds",
"fillBasicInfo": "Fill your basic info",
"aadharPanVerification": "Aadhar and PAN verification",
"linkAccountMandate": "Link account",
"loanAgreementSigning": "Loan agreement signing",
"kycVerification": "KYC Verification",
"nextPledgeFunds": "Next: Pledge Funds",
"SetMandate": "Set Mandate",
"verifyDetails": "Verify details to proceed securely",
"safeSecure": "Safe & Secure • Your data is encrypted",
"proceedToFinalStep": "Proceed to Final Step",
"startingKyc": 'Starting video KYC',
"pledgeFunds": "Pledge Funds",
"nextApplicationSubmission": "Next: Application Submission",
"otpSentMessage":
"OTP sent from MFCentral to your registered mobile number ending with XX45",
"invalidOtp": "Invalid OTP. Try again.",
"submitComplete": "Submit & Complete Application",
'eligibleUnlock': 'You are eligible to unlock up to',
'fromInvestments': 'from your investments',
'seeLoanOffers': 'See Loan Offers',
'almostThere': 'Almost there!',
'fetchingMutualFunds': 'Fetching your Mutual Funds...',
'cibilNote': "Relax, this won't affect your CIBIL score.",
'enterMobileNumber': "Enter mobile number",
'enterEmail': "Enter your Email",
'startKycProcess': "Starting KYC Process...",
'pleaseWaitWhileWePrepare': "Please wait while we prepare your verification",
};