VerifyOtpResponse class
Constructors
- VerifyOtpResponse({required bool success, String? token, String? refreshToken, String? name, String? message, String? reqId, String? topUpRedId, String? kycId, String? selfieId, String? kycStatus, PendingJourney? pendingJourney, String? lenderCode, String? broker})
- VerifyOtpResponse.error(String message)
-
factory
-
VerifyOtpResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- broker → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
-
final
- kycId → String?
-
final
- kycStatus → String?
-
final
- lenderCode → String?
-
final
- message → String?
-
final
- name → String?
-
final
- pendingJourney → PendingJourney?
-
final
- refreshToken → String?
-
final
- reqId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfieId → String?
-
final
-
final
-
final
- success → bool
-
final
- token → String?
-
final
- topUpRedId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited