LenderItem class
Constructors
Properties
-
eligibleFunds
→ List<
EligibleFund> ? -
final
- eligibleFundsCount → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- lenderCode → String?
-
final
- loanAmount → double?
-
final
- loanInterest → double?
-
final
- logo → String?
-
final
- maxEligibleLimit → double?
-
final
- minEligibleLimit → double?
-
final
- name → String?
-
final
- pf → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited