Clr class
Constructors
- Clr()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accentColor → const Color
- background → const Color
- backgroundColor → const Color
- black → const Color
- blue → const Color
- cursorColor → const Color
- cyan → const Color
- darkGrey → const Color
- errorColor → const Color
- green → const Color
- grey → const Color
- lightGrey → const Color
- magenta → const Color
- primaryColor → const Color
- primaryDarkColor → const Color
- red → const Color
- successColor → const Color
- transparent → const Color
- white → const Color
- yellow → const Color