EmStatus enum
Values
- notStarted → const EmStatus
- pending → const EmStatus
- panVerified → const EmStatus
- mfFetched → const EmStatus
- kycDone → const EmStatus
- pennyDropDone → const EmStatus
- kfsDone → const EmStatus
- mandateFail → const EmStatus
- mandateDone → const EmStatus
- completed → const EmStatus
- pledgeCompleted → const EmStatus
- loanDisbursed → const EmStatus
- loanClosed → const EmStatus
- eligibility → const EmStatus
- eligibilityChecked → const EmStatus
- vKycDone → const EmStatus
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited